@@ -24,6 +24,7 @@ use {
 };
 
 static WIX_TOOLSET: Lazy<RemoteContent> = Lazy::new(|| RemoteContent {
+    name: "WIX_TOOLSET".to_string(),
     url: "https://github.com/wixtoolset/wix3/releases/download/wix3112rtm/wix311-binaries.zip"
         .to_string(),
     sha256: "2c1888d5d1dba377fc7fa14444cf556963747ff9a0a289a3599cf09da03b9e2e".to_string(),
@@ -183,8 +184,8 @@ pub fn write_file_manifest_to_wix<W: Write, P: AsRef<Path>>(
 
         // Add `<Component>` for files in this directory.
         for (filename, (rel_path, _)) in files {
-            let guid = component_guid(id_prefix, &rel_path);
-            let id = component_id(id_prefix, &rel_path);
+            let guid = component_guid(id_prefix, rel_path);
+            let id = component_id(id_prefix, rel_path);
 
             writer.write(
                 XmlEvent::start_element("Component")
@@ -239,7 +240,7 @@ pub fn write_file_manifest_to_wix<W: Write, P: AsRef<Path>>(
                 Some(p)
             }
         }) {
-            let component_id = component_id(id_prefix, &p);
+            let component_id = component_id(id_prefix, p);
 
             writer.write(XmlEvent::start_element("ComponentRef").attr("Id", &component_id))?;
             writer.write(XmlEvent::end_element())?;
@@ -471,10 +472,7 @@ mod tests {
 
     #[test]
     fn test_file_manifest_to_wix() -> Result<()> {
-        let c = FileEntry {
-            data: vec![42].into(),
-            executable: false,
-        };
+        let c = FileEntry::from(vec![42]);
 
         let mut m = FileManifest::default();
         m.add_file_entry(Path::new("root.txt"), c.clone())?;
