@@ -225,12 +225,12 @@ impl WiXSimpleMsiBuilder {
     /// this msi installer.
     pub fn to_installer_builder<P: AsRef<Path>>(
         &self,
-        target_triple: &str,
+        arch: &str,
         build_path: P,
     ) -> Result<WiXInstallerBuilder> {
         let mut builder = WiXInstallerBuilder::new(
             self.id_prefix.clone(),
-            target_triple.to_string(),
+            arch.to_string(),
             build_path.as_ref().to_path_buf(),
         );
 
@@ -565,7 +565,7 @@ impl WiXSimpleMsiBuilder {
 
 #[cfg(test)]
 mod tests {
-    use {super::*, tugger_common::testutil::*, tugger_file_manifest::FileEntry};
+    use {super::*, tugger_common::testutil::*};
 
     #[cfg(target_family = "windows")]
     use tugger_windows_codesign::{
@@ -578,17 +578,11 @@ mod tests {
         let mut builder = WiXSimpleMsiBuilder::new("prefix", "myapp", "0.1", "author");
 
         let mut m = FileManifest::default();
-        m.add_file_entry(
-            "foo.txt",
-            FileEntry {
-                data: vec![42].into(),
-                executable: false,
-            },
-        )?;
+        m.add_file_entry("foo.txt", vec![42])?;
 
         builder.add_program_files_manifest(&m)?;
 
-        let builder = builder.to_installer_builder(env!("HOST"), DEFAULT_TEMP_DIR.path())?;
+        let builder = builder.to_installer_builder("x64", DEFAULT_TEMP_DIR.path())?;
 
         assert!(builder.wxs_files().contains_key(&PathBuf::from("main.wxs")));
         assert_eq!(builder.install_files(), &m);
@@ -606,13 +600,7 @@ mod tests {
         let mut builder = WiXSimpleMsiBuilder::new("prefix", "testapp", "0.1", "author");
 
         let mut m = FileManifest::default();
-        m.add_file_entry(
-            "foo.txt",
-            FileEntry {
-                data: vec![42].into(),
-                executable: false,
-            },
-        )?;
+        m.add_file_entry("foo.txt", vec![42])?;
 
         builder.add_program_files_manifest(&m)?;
 
@@ -632,7 +620,7 @@ mod tests {
 
         let builder = builder.auto_sign_signtool(settings);
 
-        let builder = builder.to_installer_builder(env!("HOST"), temp_dir.path())?;
+        let builder = builder.to_installer_builder("x64", temp_dir.path())?;
 
         let output_path = temp_dir.path().join("test.msi");
 
